@@ -7,7 +7,7 @@
     
     ## If database already exists, return it
     if(!is.null(.pkg.env$.google.db))
-        return(.pkg.env$.google.db);
+        return(.pkg.env$.google.db)
     
     ## Else, download it
 
@@ -18,10 +18,29 @@
     # ret = getURLContent(apiurl, ssl.verifypeer = FALSE);
 
     ## Download from my own site, faster but not as up-to-date as Google
-    doc = RCurl::getURL("http://statr.me/files/webfonts");
-    res = jsonlite::fromJSON(doc, FALSE);
-    .pkg.env$.google.db = res;
-    return(res);
+    db = paste(tempfile(), ".bz2", sep = "")
+    db = tryCatch(
+    
+    ## First try to download the database
+    {
+        utils::download.file("http://statr.me/files/webfonts.bz2", db,
+                             quiet = TRUE, mode = "wb")
+        db
+    },
+    
+    ## If not successful, use the built-in one
+    error = function(e) {
+        system.file("fonts", "webfonts.bz2", package = "sysfonts")
+    }
+    
+    )
+    
+    con = bzfile(db, "rb")
+    font_list = readLines(con)
+    close(con)
+    res = jsonlite::fromJSON(font_list, FALSE)
+    .pkg.env$.google.db = res
+    return(res)
 }
 
 .google.font.list = function()
